@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: arg.c,v 1.44 2005/05/11 13:02:46 abe Exp $";
+static char *rcsid = "$Id: arg.c,v 1.47 2008/05/09 12:54:22 abe Exp $";
 #endif
 
 
@@ -128,7 +128,6 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 	struct stat *sbp;	/* if non-NULL, pointer to stat(2) buffer
 				 * when argument count == 1 */
 {
-	unsigned char ad, an;
 	short err = 0;
 	char *fnm, *fsnm, *path;
 	int fsm, ftype, j;
@@ -146,6 +145,7 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 #endif	/* defined(CKFA_EXPDEV) */
 
 #if	defined(HASPROCFS)
+	unsigned char ad, an;
 	int pfsnl = -1;
 	pid_t pid;
 	struct procfsid *pfi;
@@ -272,7 +272,7 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 #endif	/* defined(HASSPECDEVD) */
 
 		    }
-		    sfp->i = sb.st_ino;
+		    sfp->i = (INODETYPE)sb.st_ino;
 		    sfp->mode = sb.st_mode & S_IFMT;
 		
 #if	defined(CKFA_EXPDEV)
@@ -332,7 +332,11 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 	     */
 		if (!fnm || fnm == path) {
 		    sfp->name = fnm;
+
+#if	defined(HASPROCFS)
 		    an = 0;
+#endif	/* defined(HASPROCFS) */
+
 		} else {
 		    if (!(sfp->name = mkstrcpy(fnm, (MALLOC_S *)NULL))) {
 			(void) fprintf(stderr,
@@ -340,11 +344,19 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 			safestrprt(fnm, stderr, 1);
 			Exit(1);
 		    }
+
+#if	defined(HASPROCFS)
 		    an = 1;
+#endif	/* defined(HASPROCFS) */
+
 		}
 		if (!fsnm || fsnm == path) {
 		    sfp->devnm = fsnm;
+
+#if	defined(HASPROCFS)
 		    ad = 0;
+#endif	/* defined(HASPROCFS) */
+
 		} else {
 		    if (!(sfp->devnm = mkstrcpy(fsnm, (MALLOC_S *)NULL))) {
 			(void) fprintf(stderr,
@@ -352,7 +364,11 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 			safestrprt(fsnm, stderr, 1);
 			Exit(1);
 		    }
+
+#if	defined(HASPROCFS)
 		    ad = 1;
+#endif	/* defined(HASPROCFS) */
+
 		}
 		if (!(sfp->aname = mkstrcpy(av[i], (MALLOC_S *)NULL))) {
 		    (void) fprintf(stderr,
@@ -419,7 +435,7 @@ ck_file_arg(i, ac, av, fv, rs, sbp)
 		Procfsid = pfi;
 
 # if	defined(HASPINODEN)
-		pfi->inode = (unsigned long)sfp->i;
+		pfi->inode = (INODETYPE)sfp->i;
 # endif	/* defined(HASPINODEN) */
 
 	    /*
@@ -770,7 +786,7 @@ enter_fd_lst(nm, lo, hi, excl)
 	int excl;			/* exclusion on match */
 {
 	char buf[256], *cp;
-	int dup, n;
+	int n;
 	struct fd_lst *f, *ft;
 /*
  * Don't allow a mixture of exclusions and inclusions.
@@ -937,7 +953,7 @@ enter_dir(d, descend)
 	Dstkn = Dstkx = 0;
 	Dstk = (char **)NULL;
 	(void) stkdir(dn);
-	av[0] = (dn == d) ? mkstrcpy(dn, (MALLOC_S)NULL) : dn;
+	av[0] = (dn == d) ? mkstrcpy(dn, (MALLOC_S *)NULL) : dn;
 	av[1] = (char *)NULL;
 	dn = (char *)NULL;
 	if (!ck_file_arg(0, 1, av, 1, 1, &sb)) {
@@ -1403,10 +1419,11 @@ nwad_exit:
 		    return(1);
 		}
 	    /*
-	     * The protocol name should be "tcp" or "udp".
+	     * The protocol name should be "tcp", "udp" or "udplite".
 	     */
-		if (strcasecmp(n.proto, "tcp") != 0
-		&&  strcasecmp(n.proto, "udp") != 0)
+		if ((strcasecmp(n.proto, "tcp") != 0)
+		&&  (strcasecmp(n.proto, "udp") != 0)
+		&&  (strcasecmp(n.proto, "udplite") != 0))
 		{
 		    (void) fprintf(stderr,
 			"%s: unknown protocol name (%s) in: -i ", Pn, n.proto);
@@ -1578,7 +1595,7 @@ unacc_port:
 		/*
 		 * Convert service name to port number, using already-specified
 		 * protocol name.  A '-' is taken to be part of the name; hence
-		 * the staring entry of a range can't be a service name.
+		 * the starting entry of a range can't be a service name.
 		 */
 		    for (p = wa; *wa && *wa != ','; wa++)
 			;
@@ -1913,7 +1930,8 @@ enter_uid(us)
 			lnml++;
 		    }
 		    (void) fprintf(stderr,
-			"%s: -u login name > %d characters: ", Pn, LOGINML);
+			"%s: -u login name > %d characters: ", Pn,
+			    (int)LOGINML);
 		    safestrprtn(st, lnml, stderr, 1);
 		    err = j = 1;
 		    break;
@@ -2001,7 +2019,7 @@ enter_uid(us)
 		}
 	    }
 	    if (nn) {
-		if (!(lp = mkstrcpy(lnm, (MALLOC_S)NULL))) {
+		if (!(lp = mkstrcpy(lnm, (MALLOC_S *)NULL))) {
 		    (void) fprintf(stderr, "%s: no space for login: ", Pn);
 		    safestrprt(lnm, stderr, 1);
 		    Exit(1);
