@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dnode.c,v 1.37 2008/04/15 13:31:47 abe Exp $";
+static char *rcsid = "$Id: dnode.c,v 1.38 2008/05/09 12:53:13 abe Exp $";
 #endif
 
 
@@ -524,9 +524,10 @@ process_overlaid_node:
 #if	!defined(HAS_ZFS)
 		if (!Fwarn && !zw) {
 		    (void) fprintf(stderr,
-			"%s: WARNING: no ZFS support has been defined.  See\n");
+			"%s: WARNING: no ZFS support has been defined.\n",
+			Pn);
 		    (void) fprintf(stderr,
-			"      00FAQ for more information.\n");
+			"      See 00FAQ for more information.\n");
 		    zw = 1;
 		}
 #else	/* defined(HAS_ZFS) */
@@ -757,8 +758,14 @@ process_overlaid_node:
 # endif	/* defined(HAS_UFS1_2) */
 #endif	/* FREEBSDV<2000 */
 
+#if	defined(HAS_V_LOCKF)
+	    if (v->v_lockf)
+		(void) get_lock_state((KA_T)v->v_lockf);
+#else	/* !defined(HAS_V_LOCKF) */
 	    if (i->i_lockf)
 		(void) get_lock_state((KA_T)i->i_lockf);
+#endif	/* defined(HAS_V_LOCKF) */
+
 	    break;
 
 #if	defined(HAS_ZFS)
@@ -771,8 +778,15 @@ process_overlaid_node:
 		return;
 	    }
 	    z = &zi;
+
+#if	defined(HAS_V_LOCKF)
+	    if (v->v_lockf)
+		(void) get_lock_state((KA_T)v->v_lockf);
+#else	/* !defined(HAS_V_LOCKF) */
 	    if (z->lockf)
 		(void) get_lock_state((KA_T)z->lockf);
+#endif	/* defined(HAS_V_LOCKF) */
+
 	    break;
 #endif	/* defined(HAS_ZFS) */
 
