@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1997 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dsock.c,v 1.31 2008/04/15 13:32:26 abe Exp $";
+static char *rcsid = "$Id: dsock.c,v 1.32 2008/05/09 12:53:49 abe Exp $";
 #endif
 
 
@@ -91,7 +91,7 @@ struct tcp_udp {			/* IPv4 TCP and UDP socket
 	unsigned long faddr, laddr;	/* foreign & local IPv6 addresses */
 	int fport, lport;		/* foreign & local ports */
 	unsigned long txq, rxq;		/* transmit & receive queue values */
-	int proto;			/* 0 = TCP, 1 = UDP */
+	int proto;			/* 0 = TCP, 1 = UDP, 2 = UDPLITE */
 	int state;			/* protocol state */
 	struct tcp_udp *next;
 };
@@ -103,7 +103,7 @@ struct tcp_udp6 {			/* IPv6 TCP and UDP socket
 	struct in6_addr faddr, laddr;	/* foreign and local IPv6 addresses */
 	int fport, lport;		/* foreign & local ports */
 	unsigned long txq, rxq;		/* transmit & receive queue values */
-	int proto;			/* 0 = TCP, 1 = UDP */
+	int proto;			/* 0 = TCP, 1 = UDP, 2 = UDPLITE */
 	int state;			/* protocol state */
 	struct tcp_udp6 *next;
 };
@@ -169,9 +169,14 @@ static int TcpUdp6_bucks = 0;		/* dynamically sized hash bucket
 					 * count for IPv6 TCP and UDP -- will
 					 * be a power of two */
 static char *UDP6path = (char *)NULL;	/* path to IPv6 UDP /proc information */
+static char *UDP6LITEpath = (char *)NULL;
+					/* path to IPv6 UDPLITE /proc
+					 * information */
 #endif	/* defined(HASIPv6) */
 
 static char *UDPpath = (char *)NULL;	/* path to UDP /proc information */
+static char *UDPLITEpath = (char *)NULL;
+					/* path to UDPLITE /proc information */
 static char *UNIXpath = (char *)NULL;	/* path to UNIX /proc information */
 static struct uxsin **Uxsin = (struct uxsin **)NULL;
 					/* UNIX socket info, hashed by inode */
@@ -279,7 +284,19 @@ check_tcpudp(i, p)
 	h = TCPUDPHASH(i);
 	for (tp = TcpUdp[h]; tp; tp = tp->next) {
 	    if (i == tp->inode) {
-		*p = tp->proto ? "UDP" : "TCP";
+		switch (tp->proto) {
+		case 0:
+		    *p = "TCP";
+		    break;
+		case 1:
+		    *p = "UDP";
+		    break;
+		case 2:
+		    *p = "UDPLITE";
+		    break;
+		default:
+		   *p = "unknown";
+		}
 		return(tp);
 	    }
 	}
@@ -323,7 +340,19 @@ check_tcpudp6(i, p)
 	h = TCPUDP6HASH(i);
 	for (tp6 = TcpUdp6[h]; tp6; tp6 = tp6->next) {
 	    if (i == tp6->inode) {
-		*p = tp6->proto ? "UDP" : "TCP";
+		switch (tp6->proto) {
+		case 0:
+		    *p = "TCP";
+		    break;
+		case 1:
+		    *p = "UDP";
+		    break;
+		case 2:
+		    *p = "UDPLITE";
+		    break;
+		default:
+		   *p = "unknown";
+		}
 		return(tp6);
 	    }
 	}
@@ -837,13 +866,14 @@ get_raw(p)
 
 
 /*
- * get_tcpudp() - get IPv4 TCP or UDP IPv4 net info
+ * get_tcpudp() - get IPv4 TCP, UDP or UDPLITE net info
  */
 
 static void
 get_tcpudp(p, pr, clr)
 	char *p;			/* /proc/net/{tcp,udp} path */
-	int pr;				/* protocol: 0 = TCP, 1 = UDP */
+	int pr;				/* protocol: 0 = TCP, 1 = UDP,
+					 *           2 = UDPLITE */
 	int clr;			/* 1 == clear the table */
 {
 	char buf[MAXPATHLEN], *ep, **fp;
@@ -1158,7 +1188,7 @@ get_raw6(p)
 
 
 /*
- * get_tcpudp6() - get IPv6 TCP or UDP IPv4 net info
+ * get_tcpudp6() - get IPv6 TCP, UDP or UDPLITE net info
  */
 
 static void
@@ -2098,6 +2128,12 @@ process_proc_sock(p, s, ss, l, lss)
 	    (void) free((FREE_P *)UDP6path);
 	    UDP6path = (char *)NULL;
 	}
+	if (UDP6LITEpath) {
+	    if (!Fxopt)
+		(void) get_tcpudp6(UDP6LITEpath, 2, 0);
+	    (void) free((FREE_P *)UDP6LITEpath);
+	    UDP6LITEpath = (char *)NULL;
+	}
 	if (!Fxopt && (ss & SB_INO)
 	&&  (tp6 = check_tcpudp6((INODETYPE)s->st_ino, &pr))
 	) {
@@ -2163,6 +2199,12 @@ process_proc_sock(p, s, ss, l, lss)
 	    (void) free((FREE_P *)UDPpath);
 	    UDPpath = (char *)NULL;
 	}
+	if (UDPLITEpath) {
+	    if (!Fxopt)
+		(void) get_tcpudp(UDPLITEpath, 2, 0);
+	    (void) free((FREE_P *)UDPLITEpath);
+	    UDPLITEpath = (char *)NULL;
+	}
 	if (!Fxopt && (ss & SB_INO)
 	&&  (tp = check_tcpudp((INODETYPE)s->st_ino, &pr))
 	) {
@@ -2253,6 +2295,8 @@ set_net_paths(p, pl)
 	(void) make_proc_path(p, pl, &TCPpath, &pathl, "tcp");
 	pathl = 0;
 	(void) make_proc_path(p, pl, &UDPpath, &pathl, "udp");
+	pathl = 0;
+	(void) make_proc_path(p, pl, &UDPLITEpath, &pathl, "udplite");
 
 #if	defined(HASIPv6)
 	pathl = 0;
@@ -2263,6 +2307,8 @@ set_net_paths(p, pl)
 	(void) make_proc_path(p, pl, &TCP6path, &pathl, "tcp6");
 	pathl = 0;
 	(void) make_proc_path(p, pl, &UDP6path, &pathl, "udp6");
+	pathl = 0;
+	(void) make_proc_path(p, pl, &UDP6LITEpath, &pathl, "udp6lite");
 #endif	/* defined(HASIPv6) */
 
 	pathl = 0;
