@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1994 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: dproc.c,v 1.31 2005/05/11 12:54:26 abe Exp $";
+static char *rcsid = "$Id: dproc.c,v 1.33 2008/04/15 13:32:58 abe Exp $";
 #endif
 
 #include "lsof.h"
@@ -120,7 +120,6 @@ static int Np;				/* number of P[], Pgid[] and Pid[]
 static int Npa = 0;			/* number of P[], Pgid[] and Pid[]
 					 * entries for which space has been
 					 * allocated */
-static KA_T Nproc = 0;			/* kernel's nproc address */
 static struct proc *P = NULL;		/* local proc structure table */
 static int *Pgid = NULL;		/* process group IDs for P[] entries */
 static int *Pid = NULL;			/* PIDs for P[] entries */
@@ -192,7 +191,6 @@ close_kvm()
 void
 gather_proc_info()
 {
-	MALLOC_S bc;
 	static int ft = 1;
 	int i, j;
 	struct proc *p;
@@ -220,12 +218,6 @@ gather_proc_info()
 	struct cred pc;
 #endif	/* solaris>=20500 */
 
-#if	defined(HASFSTRUCT)
-	static int npofb = 0;
-	char *pofp;
-	static char *pofb = (char *)NULL;
-#endif	/* defined(HASFSTRUCT) */
-
 #if	defined(HASZONES)
 	struct zone z;
 	int zh;
@@ -510,7 +502,6 @@ gather_proc_info()
 static void
 get_kernel_access()
 {
-	char er[64];
 	int i;
 	struct stat sb;
 	KA_T v;
@@ -624,6 +615,14 @@ get_kernel_access()
 	if (statsafely(ALLKMEM, &sb) == 0)
 	    HasALLKMEM = 1;
 
+#if	defined(HASVXFSUTIL)
+/*
+ * If the VXFS utility library is being used, attempt to get the VXFS inode
+ * offsets before setgid permission is surrendered.
+ */
+	(void) access_vxfs_ioffsets();
+#endif	/* defined(HASVXFSUTIL) */
+
 #if	defined(WILLDROPGID)
 /*
  * If Solaris kernel memory is coming from KMEM, the process is willing to
@@ -1071,7 +1070,7 @@ process_text(pa)
 	KA_T pa;			/* address space description pointer */
 {
 	struct as as;
-	int i, j, k, l;
+	int i, j, k;
 	struct seg s;
 	struct segvn_data vn;
 	avl_tree_t *avtp;
@@ -1091,14 +1090,15 @@ process_text(pa)
 /*
  * Loop through the segments.  The loop should stop when the segment
  * pointer returns to its starting point, but just in case, it's stopped
- * when MAXSEGS have been recorded or 2*MAXSEGS have been examined.
+ * when MAXSEGS unique segments have been recorded or 2*MAXSEGS segments
+ * have been examined.
  */
-	avtp = &as.a_segtree;
-
-	for (i = j = k = 0; i < MAXSEGS && j < 2*MAXSEGS; j++) {
-	    if (j == 0 ? get_first_seg(avtp, &s) : get_next_seg(avtp, &s))
+	for (avtp = &as.a_segtree, i = j = 0;
+	     (i < MAXSEGS) && (j < 2*MAXSEGS);
+	     j++)
+	{
+	    if (j ? get_next_seg(avtp, &s) : get_first_seg(avtp, &s))
 		break;
-		
 	    if ((KA_T)s.s_ops == Sgvops && s.s_data) {
 		if (kread((KA_T)s.s_data, (char *)&vn, sizeof(vn)))
 		    break;
@@ -1107,14 +1107,15 @@ process_text(pa)
 		/*
 		 * This is a virtual node segment.
 		 *
-		 * If its vnode pointer has not been seen already,
-		 * print its information.
+		 * If its vnode pointer has not been seen already, record the
+		 * vnode pointer and process the vnode.
 		 */
-		    for (l = 0; l < k; l++) {
-			if (v[l] == (KA_T)vn.vp)
+		    for (k = 0; k < i; k++) {
+			if (v[k] == (KA_T)vn.vp)
 			    break;
 		    }
-		    if (l >= k) {
+		    if (k >= i) {
+			v[i++] = (KA_T)vn.vp;
 			alloc_lfile(" txt", -1);
 
 # if	defined(FILEPTR)
@@ -1122,11 +1123,8 @@ process_text(pa)
 # endif	/* defined(FILEPTR) */
 
 			process_node((KA_T)vn.vp);
-			if (Lf->sf) {
+			if (Lf->sf)
 			    link_lfile();
-			    i++;
-			}
-			v[k++] = (KA_T)vn.vp;
 		    }
 		}
 	    }
@@ -1146,7 +1144,7 @@ process_text(pa)
 	KA_T pa;			/* address space description pointer */
 {
 	struct as as;
-	int i, j, k, l;
+	int i, j, k;
 	struct seg s;
 	struct segvn_data vn;
 	KA_T v[MAXSEGS];
@@ -1165,10 +1163,13 @@ process_text(pa)
 /*
  * Loop through the segments.  The loop should stop when the segment
  * pointer returns to its starting point, but just in case, it's stopped
- * when MAXSEGS have been recorded or 2*MAXSEGS have been examined.
+ * when MAXSEGS unique segments have been recorded or 2*MAXSEGS segments
+ * have been examined.
  */
-	s.s_next = as.a_segs;
-	for (i = j = k = 0; i < MAXSEGS && j < 2*MAXSEGS; j++) {
+	for (s.s_next = as.a_segs, i = j = 0;
+	     i < MAXSEGS && j < 2*MAXSEGS;
+	     j++)
+	{
 	    if (!s.S_NEXT
 	    ||  kread((KA_T)s.S_NEXT, (char *)&s, sizeof(s)))
 		break;
@@ -1180,14 +1181,15 @@ process_text(pa)
 		/*
 		 * This is a virtual node segment.
 		 *
-		 * If its vnode pointer has not been seen already,
-		 * print its information.
+		 * If its vnode pointer has not been seen already, record the
+		 * vnode pointer and process the vnode.
 		 */
-		    for (l = 0; l < k; l++) {
-			if (v[l] == (KA_T)vn.vp)
+		    for (k = 0; k < i; k++) {
+			if (v[k] == (KA_T)vn.vp)
 			    break;
 		    }
-		    if (l >= k) {
+		    if (k >= i) {
+			v[i++] = (KA_T)vn.vp;
 			alloc_lfile(" txt", -1);
 
 # if	defined(FILEPTR)
@@ -1195,11 +1197,8 @@ process_text(pa)
 # endif	/* defined(FILEPTR) */
 
 			process_node((KA_T)vn.vp);
-			if (Lf->sf) {
+			if (Lf->sf)
 			    link_lfile();
-			    i++;
-			}
-			v[k++] = (KA_T)vn.vp;
 		    }
 		}
 	    }
@@ -1283,7 +1282,6 @@ readkam(addr)
 	register int i;
 	register kvmhash_t *kp, *kpp;
 	static KA_T kas = (KA_T)NULL;
-	size_t sz;
 
 	if (addr)
 	    kas = addr;
@@ -1303,7 +1301,7 @@ readkam(addr)
 		{
 		     (void) fprintf(stderr,
 			"%s: no space (%d) for KVM hash buckets\n",
-			Pn, (KVMHASHBN * sizeof(kvmhash_t *)));
+			Pn, (int)(KVMHASHBN * sizeof(kvmhash_t *)));
 		    Exit(1);
 		}
 	    } else if (!addr) {
@@ -1399,7 +1397,7 @@ read_proc()
 	     */
 		if (!PrAct || kread(PrAct, (char *)&paf, sizeof(pa))) {
 		    (void) fprintf(stderr, "%s: can't read practive from %s\n",
-			print_kptr(PrAct, (char *)NULL, 0));
+			Pn, print_kptr(PrAct, (char *)NULL, 0));
 		    Exit(1);
 		}
 		ct = 1;
@@ -1717,7 +1715,7 @@ ncache_isroot(va, cp)
 		buf[len++] = '/';
 	    (void) strcpy(&buf[len], cp);
 	    if (statsafely(buf, &sb) != 0
-	    ||  (unsigned long)sb.st_ino != Lf->inode)
+	    ||  (INODETYPE)sb.st_ino != Lf->inode)
 		return(0);
 	}
 /*
@@ -1757,7 +1755,6 @@ ncache_load()
 	static nc_hash_t *khl = (nc_hash_t *)NULL;
 	KA_T kn;
 	static ncache_t *nc = (ncache_t *)NULL;
-	ncache_t ncc;
 	static int Nch = 0;
 	static int nmo = 0;
 	KA_T v;
@@ -1970,7 +1967,7 @@ no_local_space:
 				   (MALLOC_S)(Nla * sizeof(struct l_nch))))
 		    ) {
 			(void) fprintf(stderr,
-			    "%s: can't enlarge local name cache: %s\n", Pn);
+			    "%s: can't enlarge local name cache\n", Pn);
 			Exit(1);
 		    }
 		    lc = &Ncache[n];
@@ -2106,7 +2103,7 @@ ncache_lookup(buf, blen, fp)
 		if (!mtp->dir || !mtp->inode)
 		    continue;
 		if (Lf->dev == mtp->dev
-		&&  (unsigned long)mtp->inode == Lf->inode
+		&&  mtp->inode == Lf->inode
 		&&  strcmp(mtp->dir, Lf->fsdir) == 0)
 		    return(cp);
 	    }
